@@ -3,6 +3,7 @@ import logging
 from django.conf import settings
 from django.db.models import DecimalField, Model, DateField
 
+import kaf_pas
 from isc_common import Wrapper
 from isc_common.common import blinkString
 from isc_common.fields.name_field import NameField
@@ -15,8 +16,8 @@ from isc_common.ws.webSocket import WebSocket
 from kaf_pas.ckk.models.ed_izm import Ed_izm
 from kaf_pas.ckk.models.item import Item
 from kaf_pas.ckk.models.locations import Locations
+from kaf_pas.planing.models.operations import Operations
 from kaf_pas.production.models.launches import Launches
-from kaf_pas.production.models.operations import Operations
 from kaf_pas.production.models.resource import Resource
 from kaf_pas.sales.models.demand import Demand
 
@@ -63,7 +64,7 @@ class BuffersManager(AuditManager):
 
     @staticmethod
     def get_buffer_oddment_value(value):
-        if value == None:
+        if value is None:
             return 0
         return blinkString(text=DecimalToStr(value), blink=True if value < 0 else False, bold=True, color='green' if value > 0 else 'red')
 
@@ -113,7 +114,8 @@ class Buffers(Model):
     demand = ForeignKeyProtect(Demand, null=True, blank=True)
     edizm = ForeignKeyProtect(Ed_izm, null=True, blank=True)
     item = ForeignKeyProtect(Item)
-    last_operation = ForeignKeyProtect(Operations, null=True, blank=True)
+    last_tech_operation = ForeignKeyProtect(Operations, null=True, blank=True)
+    last_operation = ForeignKeyProtect(kaf_pas.production.models.operations.Operations, null=True, blank=True)
     last_operation_full_name = NameField(null=True, blank=True)
     launch = ForeignKeyProtect(Launches, null=True, blank=True)
     resource = ForeignKeyProtect(Resource, null=True, blank=True)
