@@ -4,10 +4,10 @@ from bitfield import BitField, BitHandler
 from django import db
 from django.conf import settings
 from django.db import transaction, connection
-from django.db.models import PositiveIntegerField, BigIntegerField, UniqueConstraint, Q
+from django.db.models import PositiveIntegerField, BigIntegerField, UniqueConstraint, Q, ProtectedError
 from django.forms import model_to_dict
 
-from isc_common import setAttr, delAttr, get_list_nums_key_dict
+from isc_common import setAttr, delAttr
 from isc_common.auth.models.user import User
 from isc_common.bit import TurnBitOn
 from isc_common.common.functions import delete_dbl_spaces
@@ -49,15 +49,21 @@ class ItemQuerySet(CommonManagetWithLookUpFieldsQuerySet):
 
         with transaction.atomic():
             delAttr(kwargs, 'used')
+            creator_id = kwargs.get('creator_id')
+            if creator_id is None:
+                creator_id = self[0].creator.id
+                setAttr(kwargs, 'creator_id', creator_id)
 
             res = super().update(**kwargs)
 
+            item_id = self[0].id
             delAttr(kwargs, 'id')
             delAttr(kwargs, 'creator')
             delAttr(kwargs, 'used')
-            setAttr(kwargs, 'hcreator', res.creator)
+            setAttr(kwargs, 'hcreator_id', kwargs.get('creator_id'))
+            delAttr(kwargs, 'creator_id')
             delAttr(kwargs, 'parent_id')
-            setAttr(kwargs, 'item', res)
+            setAttr(kwargs, 'item_id', item_id)
             Item_history.objects.get_or_create(**kwargs)
             return res
 
@@ -71,11 +77,10 @@ class ItemManager(CommonManagetWithLookUpFieldsManager):
         data = request.get_data()
         _data = data.copy()
 
-        parent = _data.get('parent')
-        if parent:
-            delAttr(_data, 'parent')
-            setAttr(_data, 'parent_id', parent)
-
+        parent_id = _data.get('id')
+        delAttr(_data, 'parent')
+        delAttr(_data, 'parent_id')
+        delAttr(_data, 'id')
         delAttr(_data, 'STMP_1__value_str')
         delAttr(_data, 'STMP_2__value_str')
 
@@ -91,10 +96,13 @@ class ItemManager(CommonManagetWithLookUpFieldsManager):
         setAttr(_data, 'props', props)
         setAttr(_data, 'creator', request.user)
 
-        res = super().create(**_data)
-        logger.debug(f'Added: {res}')
+        # 'STMP_1', 'STMP_2', 'lotsman_document_id', 'lotsman_type_id', 'props', 'version'
+        res, created = super().get_or_create(**_data)
 
-        item_refs, create = Item_refs.objects.get_or_create(parent_id=_data.get('parent_id'), child=res)
+        if created:
+            logger.debug(f'Added: {res}')
+
+        item_refs, create = Item_refs.objects.get_or_create(parent_id=parent_id, child=res)
         if create:
             logger.debug(f'Added item_ref: {item_refs}')
 
@@ -118,9 +126,9 @@ class ItemManager(CommonManagetWithLookUpFieldsManager):
         STMP_2 = item.STMP_2.value_str if item.STMP_2 else None
         STMP_1 = item.STMP_1.value_str if item.STMP_1 else None
 
-        if STMP_2 == None:
+        if STMP_2 is None:
             item_query = Item.objects.filter(STMP_1__value_str__delete_dbl_spaces=delete_dbl_spaces(STMP_1))
-        elif STMP_1 == None:
+        elif STMP_1 is None:
             item_query = Item.objects.filter(STMP_2__value_str__delete_dbl_spaces=delete_dbl_spaces(STMP_2))
         else:
             item_query = Item.objects.filter(STMP_1__value_str__delete_dbl_spaces=delete_dbl_spaces(STMP_1), STMP_2__value_str__delete_dbl_spaces=delete_dbl_spaces(STMP_2))
@@ -137,9 +145,9 @@ class ItemManager(CommonManagetWithLookUpFieldsManager):
         STMP_2 = item.STMP_2.value_str if item.STMP_2 else None
         STMP_1 = item.STMP_1.value_str if item.STMP_1 else None
 
-        if STMP_2 == None:
+        if STMP_2 is None:
             item_query = Item.objects.filter(STMP_1__value_str__delete_dbl_spaces__contains=delete_dbl_spaces(STMP_1))
-        elif STMP_1 == None:
+        elif STMP_1 is None:
             item_query = Item.objects.filter(STMP_2__value_str__delete_dbl_spaces__contains=delete_dbl_spaces(STMP_2))
         else:
             item_query = Item.objects.filter(STMP_1__value_str__delete_dbl_spaces__contains=delete_dbl_spaces(STMP_1), STMP_2__value_str__delete_dbl_spaces__contains=delete_dbl_spaces(STMP_2))
@@ -151,9 +159,9 @@ class ItemManager(CommonManagetWithLookUpFieldsManager):
         STMP_1 = kwargs.get('STMP_1')
         STMP_2 = kwargs.get('STMP_2')
 
-        if STMP_2 == None:
+        if STMP_2 is None:
             item_query = Item.objects.filter(STMP_1__value_str__delete_dbl_spaces=delete_dbl_spaces(STMP_1))
-        elif STMP_1 == None:
+        elif STMP_1 is None:
             item_query = Item.objects.filter(STMP_2__value_str__delete_dbl_spaces=delete_dbl_spaces(STMP_2))
         else:
             item_query = Item.objects.filter(STMP_1__value_str__delete_dbl_spaces=delete_dbl_spaces(STMP_1), STMP_2__value_str__delete_dbl_spaces=delete_dbl_spaces(STMP_2))
@@ -165,9 +173,9 @@ class ItemManager(CommonManagetWithLookUpFieldsManager):
         STMP_1 = kwargs.get('STMP_1')
         STMP_2 = kwargs.get('STMP_2')
 
-        if STMP_2 == None:
+        if STMP_2 is None:
             item_query = Item.objects.filter(STMP_1__value_str__delete_dbl_spaces__contains=delete_dbl_spaces(STMP_1))
-        elif STMP_1 == None:
+        elif STMP_1 is None:
             item_query = Item.objects.filter(STMP_2__value_str__delete_dbl_spaces__contains=delete_dbl_spaces(STMP_2))
         else:
             item_query = Item.objects.filter(STMP_1__value_str__delete_dbl_spaces__contains=delete_dbl_spaces(STMP_1), STMP_2__value_str__delete_dbl_spaces__contains=delete_dbl_spaces(STMP_2))
@@ -196,16 +204,17 @@ class ItemManager(CommonManagetWithLookUpFieldsManager):
     @staticmethod
     def delete_recursive(item_id, delete_lines=False, soft_delete=None, user=None, props=TurnBitOn(0, 0), document=None, show_progress=True):
         from kaf_pas.ckk.models.item_document import Item_document
+        from kaf_pas.ckk.models.item_history import Item_history
         from kaf_pas.ckk.models.item_image_refs import Item_image_refs
         from kaf_pas.ckk.models.item_line import Item_line
         from kaf_pas.ckk.models.item_refs import Item_refs
         from kaf_pas.production.models.operations_item import Operations_item
-        from kaf_pas.ckk.models.tmp_item_refs import Tmp_Item_refsManager
+        from kaf_pas.ckk.models.item_varians import Item_varians
 
         key = 'ItemManager.delete_recursive'
         settings.LOCKS.acquire(key)
         item_lotsman_document_cnt = 0
-        if document != None:
+        if document is not None:
             if ItemManager.check_4_production(item=item_id) == True:
                 settings.LOCKS.release(key)
                 return 2
@@ -253,18 +262,24 @@ class ItemManager(CommonManagetWithLookUpFieldsManager):
                 with transaction.atomic():
                     try:
                         item = Item.objects.get(id=item_id)
-                        if cnt == 0:
+                        if cnt == 1:
                             Item_refs.objects1.filter(parent=item).delete_with_checked()
+                            Item_refs.objects1.filter(child=item).delete_with_checked()
                             Item_line.objects.filter(parent=item).delete()
+                            Item_line.objects.filter(child=item).delete()
+                            Item_history.objects.filter(item=item).delete()
+                            Item_varians.objects.filter(parent=item).delete()
+                            Item_varians.objects.filter(child=item).delete()
                             item.delete()
                         else:
-                            if progress != None:
+                            if progress is not None:
                                 progress.setContentsLabel(f'''<h3>Удаление товарной позиции ({item.STMP_1.value_str if item.STMP_1 else ''} : {item.STMP_2.value_str if item.STMP_2 else ''}).</h3>''')
 
+                            # 3572269
                             for item in Item_refs.objects.get_descendants(id=item_id, order_by_clause='order by level desc', sql_text=sql_text):
                                 _continue = False
-                                if soft_delete == None:
-                                    if document != None:
+                                if soft_delete is None:
+                                    if document is not None:
                                         if ItemManager.check_4_production(item=item.child_id) == True:
                                             _continue = True
 
@@ -272,6 +287,8 @@ class ItemManager(CommonManagetWithLookUpFieldsManager):
                                         _continue = False
                                         continue
 
+                                    Item_varians.objects.filter(parent=item.parent, child=item.child).delete()
+
                                     Item_image_refs.objects.filter(item_id=item.child_id).delete()
 
                                     if delete_lines:
@@ -286,7 +303,7 @@ class ItemManager(CommonManagetWithLookUpFieldsManager):
 
                                     Item_document.objects.filter(item_id=item.child_id).delete()
 
-                                    Tmp_Item_refsManager.create()
+                                    Item_history.objects.filter(item=item.child).delete()
                                     Item.objects.filter(id=item.child_id).delete()
                                 else:
                                     if soft_delete == 'hide':
@@ -296,7 +313,7 @@ class ItemManager(CommonManagetWithLookUpFieldsManager):
                                     else:
                                         raise Exception(f'soft_delete : {soft_delete} this unknown mode')
 
-                                if progress != None:
+                                if progress is not None:
                                     if progress.step() != 0:
                                         settings.LOCKS.release(key)
                                         raise ProgressDroped(progress_deleted)
@@ -382,12 +399,78 @@ class ItemManager(CommonManagetWithLookUpFieldsManager):
 
         return _data
 
+    @staticmethod
+    def replaceItems(dropRecords, targetRecord, func_after=None):
+        from kaf_pas.ckk.models.item_refs import Item_refs
+        from kaf_pas.ckk.models.item_line import Item_line
+
+        res = 0
+        for dropRecord in dropRecords:
+            item_refs, created = Item_refs.objects.get_or_create(parent_id=targetRecord.get('parent_id'), child_id=dropRecord.get('id'))
+            if not created:
+                item_refs.soft_restore()
+
+            res += 1
+
+            item_line = model_to_dict(Item_line.objects.get(parent_id=targetRecord.get('parent_id'), child_id=targetRecord.get('id')))
+
+            delAttr(item_line, 'id')
+            delAttr(item_line, 'parent')
+            delAttr(item_line, 'child')
+            setAttr(item_line, 'SPC_CLM_NAME_id', dropRecord.get('STMP_1_id'))
+            delAttr(item_line, 'SPC_CLM_NAME')
+            setAttr(item_line, 'SPC_CLM_MARK_id', dropRecord.get('STMP_2_id'))
+            delAttr(item_line, 'SPC_CLM_MARK')
+            setAttr(item_line, 'SPC_CLM_FORMAT_id', item_line.get('SPC_CLM_FORMAT'))
+            delAttr(item_line, 'SPC_CLM_FORMAT')
+            setAttr(item_line, 'SPC_CLM_ZONE_id', item_line.get('SPC_CLM_ZONE'))
+            delAttr(item_line, 'SPC_CLM_ZONE')
+            setAttr(item_line, 'SPC_CLM_POS_id', item_line.get('SPC_CLM_POS'))
+            delAttr(item_line, 'SPC_CLM_POS')
+            setAttr(item_line, 'SPC_CLM_COUNT_id', item_line.get('SPC_CLM_COUNT'))
+            delAttr(item_line, 'SPC_CLM_COUNT')
+            setAttr(item_line, 'SPC_CLM_NOTE_id', item_line.get('SPC_CLM_NOTE'))
+            delAttr(item_line, 'SPC_CLM_NOTE')
+            setAttr(item_line, 'SPC_CLM_MASSA_id', item_line.get('SPC_CLM_MASSA'))
+            delAttr(item_line, 'SPC_CLM_MASSA')
+            setAttr(item_line, 'SPC_CLM_MATERIAL_id', item_line.get('SPC_CLM_MATERIAL'))
+            delAttr(item_line, 'SPC_CLM_MATERIAL')
+            setAttr(item_line, 'SPC_CLM_USER_id', item_line.get('SPC_CLM_USER'))
+            delAttr(item_line, 'SPC_CLM_USER')
+            setAttr(item_line, 'SPC_CLM_KOD_id', item_line.get('SPC_CLM_KOD'))
+            delAttr(item_line, 'SPC_CLM_KOD')
+            setAttr(item_line, 'SPC_CLM_FACTORY_id', item_line.get('SPC_CLM_FACTORY'))
+            delAttr(item_line, 'SPC_CLM_FACTORY')
+
+            item_line, created = Item_line.objects.get_or_create(
+                parent_id=targetRecord.get('parent_id'),
+                child_id=dropRecord.get('id'),
+                defaults=item_line
+            )
+            if not created:
+                item_line.soft_restore()
+            res += 1
+
+            try:
+                Item_refs.objects1.filter(parent_id=targetRecord.get('parent_id'), child_id=targetRecord.get('id')).delete_with_checked()
+            except ProtectedError:
+                Item_refs.objects1.filter(parent_id=targetRecord.get('parent_id'), child_id=targetRecord.get('id')).soft_delete()
+
+            try:
+                Item_line.objects.filter(parent_id=targetRecord.get('parent_id'), child_id=targetRecord.get('id')).delete()
+            except ProtectedError:
+                Item_line.objects.filter(parent_id=targetRecord.get('parent_id'), child_id=targetRecord.get('id')).soft_delete()
+
+            if callable(func_after):
+                func_after(dropRecord, targetRecord)
+
+        return res
+
     def updateFromRequest(self, request, removed=None, function=None):
         from kaf_pas.ckk.models.item_refs import Item_refs
         from kaf_pas.ckk.models.item_line import Item_line
 
-        if not isinstance(request, DSRequest):
-            request = DSRequest(request=request)
+        request = DSRequest(request=request)
         data = request.get_data()
 
         with transaction.atomic():
@@ -406,59 +489,65 @@ class ItemManager(CommonManagetWithLookUpFieldsManager):
                     res += 1
                 return res
             elif data.get('mode') == 'replace':
-                res = 0
-                for dropRecord in dropRecords:
-                    Item_refs.objects.create(parent_id=targetRecord.get('parent_id'), child_id=dropRecord.get('id'))
-                    res += 1
-
-                    item_line = model_to_dict(Item_line.objects.get(parent_id=targetRecord.get('parent_id'), child_id=targetRecord.get('id')))
-                    delAttr(item_line, 'id')
-                    delAttr(item_line, 'parent')
-                    delAttr(item_line, 'child')
-                    setAttr(item_line, 'parent_id', targetRecord.get('parent_id'))
-                    setAttr(item_line, 'child_id', dropRecord.get('id'))
-                    setAttr(item_line, 'SPC_CLM_NAME_id', dropRecord.get('STMP_1_id'))
-                    delAttr(item_line, 'SPC_CLM_NAME')
-                    setAttr(item_line, 'SPC_CLM_MARK_id', dropRecord.get('STMP_2_id'))
-                    delAttr(item_line, 'SPC_CLM_MARK')
-                    setAttr(item_line, 'SPC_CLM_FORMAT_id', item_line.get('SPC_CLM_FORMAT'))
-                    delAttr(item_line, 'SPC_CLM_FORMAT')
-                    setAttr(item_line, 'SPC_CLM_ZONE_id', item_line.get('SPC_CLM_ZONE'))
-                    delAttr(item_line, 'SPC_CLM_ZONE')
-                    setAttr(item_line, 'SPC_CLM_POS_id', item_line.get('SPC_CLM_POS'))
-                    delAttr(item_line, 'SPC_CLM_POS')
-                    setAttr(item_line, 'SPC_CLM_COUNT_id', item_line.get('SPC_CLM_COUNT'))
-                    delAttr(item_line, 'SPC_CLM_COUNT')
-                    setAttr(item_line, 'SPC_CLM_NOTE_id', item_line.get('SPC_CLM_NOTE'))
-                    delAttr(item_line, 'SPC_CLM_NOTE')
-                    setAttr(item_line, 'SPC_CLM_MASSA_id', item_line.get('SPC_CLM_MASSA'))
-                    delAttr(item_line, 'SPC_CLM_MASSA')
-                    setAttr(item_line, 'SPC_CLM_MATERIAL_id', item_line.get('SPC_CLM_MATERIAL'))
-                    delAttr(item_line, 'SPC_CLM_MATERIAL')
-                    setAttr(item_line, 'SPC_CLM_USER_id', item_line.get('SPC_CLM_USER'))
-                    delAttr(item_line, 'SPC_CLM_USER')
-                    setAttr(item_line, 'SPC_CLM_KOD_id', item_line.get('SPC_CLM_KOD'))
-                    delAttr(item_line, 'SPC_CLM_KOD')
-                    setAttr(item_line, 'SPC_CLM_FACTORY_id', item_line.get('SPC_CLM_FACTORY'))
-                    delAttr(item_line, 'SPC_CLM_FACTORY')
-                    Item_line.objects.create(**item_line)
-                    res += 1
-
-                    Item_refs.objects.filter(parent_id=targetRecord.get('parent_id'), child_id=targetRecord.get('id')).delete()
-                    Item_line.objects.filter(parent_id=targetRecord.get('parent_id'), child_id=targetRecord.get('id')).delete()
-
-                    try:
-                        Item.objects.filter(id=targetRecord.get('id')).delete()
-                    except Exception as ex:
-                        logger.debug(ex)
-
-                return res
-
+                return ItemManager.replaceItems(dropRecords=dropRecords, targetRecord=targetRecord)
             else:
-                res = []
-                for _data in get_list_nums_key_dict(data):
-                    res.append(ItemManager.rec(_data.copy()))
-                return res
+                # res = []
+                _data = ItemManager.rec(data.copy())
+
+                update_dict = dict(
+                    STMP_1_id=_data.get('STMP_1_id'),
+                    STMP_2_id=_data.get('STMP_2_id'),
+                    version=_data.get('version'),
+                    document_id=_data.get('document_id'),
+                    lotsman_document_id=_data.get('lotsman_document_id'),
+                    lotsman_type_id=_data.get('lotsman_type_id'),
+                    creator_id=_data.get('creator_id'),
+                )
+                Item.objects.filter(id=_data.get('id')).update(**update_dict)
+
+                refs_props = _data.get('refs_props')
+                if refs_props is not None:
+                    refs_id = _data.get('refs_id')
+                    if _data.get('used') == True:
+                        refs_props |= Item_refs.props.used
+                    else:
+                        refs_props &= ~Item_refs.props.used
+
+                    refs_data = dict()
+                    setAttr(refs_data, 'props', refs_props)
+
+                    Item_refs.objects.update_or_create(id=refs_id, defaults=refs_data)
+
+                return _data
+
+    def replaceFromRequest(self, request):
+
+        request = DSRequest(request=request)
+        data = request.get_data()
+
+        def func_after(dropRecord, targetRecord):
+            from kaf_pas.ckk.models.item_varians import Item_varians
+            from kaf_pas.ckk.models.item_view import Item_viewManager
+
+            for item_varians in Item_varians.objects.filter(
+                    parent_id=targetRecord.get('parent_id'),
+                    child_id=targetRecord.get('id'),
+                    refs_props=targetRecord.get('refs_props')):
+                item_varians.child_id = dropRecord.get('id')
+                item_varians.save()
+
+            # Item_viewManager.fullRows()
+            Item_viewManager.refreshRows(dict(
+                id=dropRecord.get('id'),
+                parent_id=targetRecord.get('parent_id')
+            ))
+
+        with transaction.atomic():
+            targetRecord = data.get('targetRecord')
+            dropRecords = data.get('dropRecords')
+            dropRecords = map(lambda x: dict(id=x.get('item_id'), STMP_1_id=x.get('STMP_1_id'), STMP_2_id=x.get('STMP_2_id')), dropRecords)
+            res = ItemManager.replaceItems(dropRecords=dropRecords, targetRecord=targetRecord, func_after=func_after)
+            return res
 
     def deleteFromRequest(self, request, removed=None, ):
         from kaf_pas.ckk.models.item_refs import Item_refs
@@ -494,7 +583,7 @@ class ItemManager(CommonManagetWithLookUpFieldsManager):
 
                     if isinstance(records, list):
                         for record in records:
-                            if record.get('parent_id') == None:
+                            if record.get('parent_id') is None:
                                 res, _ = Item_refs.objects1.filter(child_id=record.get('id'), parent__isnull=True).delete_with_checked()
                             else:
                                 res, _ = Item_refs.objects1.filter(child_id=record.get('id'), parent_id=record.get('parent_id')).delete_with_checked()
@@ -532,10 +621,10 @@ class ItemManager(CommonManagetWithLookUpFieldsManager):
         value_str = data.get(f'{attr_type__code}__value_str')
         value_int = data.get(f'{attr_type__code}__value_int')
 
-        if value_str == None and value_int != None:
+        if value_str is None and value_int is not None:
             value_str = str(value_int)
 
-        if value_str == None:
+        if value_str is None:
             return None
 
         res, created = Document_attributesManager.get_or_create_attribute(attr_codes=attr_type__code, value_str=value_str)
@@ -568,7 +657,7 @@ class ItemManager(CommonManagetWithLookUpFieldsManager):
                 return version
             else:
                 version = query.order_by('-version')[0].version
-                if version == None:
+                if version is None:
                     version = 1
                 else:
                     version += inc
@@ -727,18 +816,18 @@ class Item(AuditModel):
 
     @property
     def item_name(self):
-        if self.STMP_1 != None and self.STMP_2 != None:
+        if self.STMP_1 is not None and self.STMP_2 is not None:
             return f'{get_NoneStr(self.STMP_1.value_str)}: {get_NoneStr(self.STMP_2.value_str)}'
-        elif self.STMP_1 == None and self.STMP_2 != None:
+        elif self.STMP_1 is None and self.STMP_2 is not None:
             return get_NoneStr(self.STMP_2.value_str)
-        elif self.STMP_1 != None and self.STMP_2 == None:
+        elif self.STMP_1 is not None and self.STMP_2 is None:
             return get_NoneStr(self.STMP_1.value_str)
         else:
             return 'Неизвестен'
 
     @staticmethod
     def get_vaslue_str(doc_attr):
-        if doc_attr.value_str == None:
+        if doc_attr.value_str is None:
             return None
         return doc_attr.value_str.strip() if doc_attr else None
 
