@@ -27,13 +27,13 @@ logger = logging.getLogger(__name__)
 class Item_lineQuerySet(AuditQuerySet):
 
     def _check(self, **kwargs):
-        if kwargs.get('parent') != None:
+        if kwargs.get('parent') is not None:
             if kwargs.get('parent' == kwargs.get('child')):
                 raise Exception('Attempt to write circular reference')
 
     def _checkDefaults(self, defaults):
-        if defaults != None:
-            if (defaults.get("SPC_CLM_MARK_id") == None and defaults.get("SPC_CLM_NAME_id") == None) and (defaults.get("SPC_CLM_MARK") == None and defaults.get("SPC_CLM_NAME") == None):
+        if defaults is not None:
+            if (defaults.get("SPC_CLM_MARK_id") is None and defaults.get("SPC_CLM_NAME_id") is None) and (defaults.get("SPC_CLM_MARK") is None and defaults.get("SPC_CLM_NAME") is None):
                 raise Exception(f'SPC_CLM_MARK and SPC_CLM_NAME not been Null together. ({defaults})')
 
     def create(self, **kwargs):
@@ -41,7 +41,9 @@ class Item_lineQuerySet(AuditQuerySet):
         section = kwargs.get('section')
         section_num = Item_lineManager.section_num(section)
         setAttr(kwargs, 'section_num', section_num)
-        return super().create(**kwargs)
+
+        res = super().create(**kwargs)
+        return res
 
     def get_or_create(self, defaults=None, **kwargs):
         self._check(**kwargs)
@@ -64,6 +66,7 @@ class Item_lineQuerySet(AuditQuerySet):
         setAttr(kwargs, 'section_num', section_num)
         delAttr(kwargs, 'confirmed')
         delAttr(kwargs, 'edizm__name')
+        delAttr(kwargs, '_name')
         return super().update(**kwargs)
 
     def update_or_create(self, defaults=None, **kwargs):
@@ -135,7 +138,7 @@ class Item_lineManager(TreeAuditModelManager):
     def getIcon(record):
         if record.isFolder:
             return 'folder_256.png'
-        elif record.section != None:
+        elif record.section is not None:
             _section = record.section.lower()
             if _section == 'документация':
                 return 'documentation.png'
@@ -162,11 +165,11 @@ class Item_lineManager(TreeAuditModelManager):
 
     @property
     def item_name(self):
-        if self.SPC_CLM_NAME != None and self.SPC_CLM_MARK != None:
+        if self.SPC_CLM_NAME is not None and self.SPC_CLM_MARK is not None:
             return f'{self.SPC_CLM_NAME.value_str}: {self.SPC_CLM_MARK.value_str}'
-        elif self.SPC_CLM_NAME == None and self.SPC_CLM_MARK != None:
+        elif self.SPC_CLM_NAME is None and self.SPC_CLM_MARK is not None:
             return self.SPC_CLM_MARK.value_str
-        elif self.SPC_CLM_NAME != None and self.SPC_CLM_MARK == None:
+        elif self.SPC_CLM_NAME is not None and self.SPC_CLM_MARK is None:
             return self.SPC_CLM_NAME.value_str
         else:
             return 'Неизвестен'
@@ -178,11 +181,11 @@ class Item_lineManager(TreeAuditModelManager):
         parent_id = data.get('parent_id')
         child_id = data.get('child_id')
 
-        if parent_id == None:
-            raise Exception('parent_id == None')
+        if parent_id is None:
+            raise Exception('parent_id is None')
 
-        if child_id == None:
-            raise Exception('child_id == None')
+        if child_id is None:
+            raise Exception('child_id is None')
 
         with transaction.atomic():
 
@@ -206,12 +209,18 @@ class Item_lineManager(TreeAuditModelManager):
                 subsection=data.get('subsection'),
             )
 
-            if data.get('SPC_CLM_MARK_id') == None and data.get('SPC_CLM_NAME_id') == None:
+            if data.get('SPC_CLM_MARK_id') is None and data.get('SPC_CLM_NAME_id') is None:
                 raise Exception(f'SPC_CLM_MARK and SPC_CLM_NAME not been Null together. ({self.model})')
 
             Item_refs.objects.get_or_create(child_id=child_id, parent_id=parent_id)
 
-            res = super().create(**_data)
+            parent_id = _data.get('parent_id')
+            delAttr(_data, 'parent_id')
+
+            child_id = _data.get('child_id')
+            delAttr(_data, 'child_id')
+
+            res, _ = super().get_or_create(parent_id=parent_id, child_id=child_id, defaults=_data)
             setAttr(data, 'id', res.id)
         return data
 
@@ -297,19 +306,19 @@ class Item_lineManager(TreeAuditModelManager):
         for key, val in data.items():
             if str(key).find('SPC_CLM_') != -1:
                 if str(key).find('_id') != -1:
-                    if val != None:
+                    if val is not None:
                         setAttr(params, key, val)
                 elif str(key).find('__value_str') != -1:
-                    if val != None:
+                    if val is not None:
                         setAttr(params, key, val)
                 elif str(key).find('__value_int') != -1:
-                    if val != None:
+                    if val is not None:
                         setAttr(params, key, val)
             else:
                 setAttr(_data, key, val)
 
         with transaction.atomic():
-            res_params=dict()
+            res_params = dict()
             for key, val in params.items():
                 idx = str(key).find('_id')
                 if idx != -1:
@@ -317,7 +326,7 @@ class Item_lineManager(TreeAuditModelManager):
                     param_str = params.get(f'{_key}__value_str')
                     param_int = params.get(f'{_key}__value_int')
 
-                    if param_int != None:
+                    if param_int is not None:
                         if StrToNumber(param_str) != param_int:
                             param_str = str(param_int)
 
@@ -362,7 +371,7 @@ class Item_lineManager(TreeAuditModelManager):
             with transaction.atomic():
                 progress.setContentsLabel('<b>Создание строк детализации</b>')
                 for record in data.get('records'):
-                    if record.get("parent_id") == None:
+                    if record.get("parent_id") is None:
                         raise Exception('Верхний уровень не подлежит внесению в детализацию.')
 
                     query = Item_line_view.objects.filter(
@@ -419,10 +428,10 @@ class Item_lineManager(TreeAuditModelManager):
         value_str = data.get(f'{attr_type__code}__value_str')
         value_int = data.get(f'{attr_type__code}__value_int')
 
-        if value_str == None and value_int != None:
+        if value_str is None and value_int is not None:
             value_str = str(value_int)
 
-        if value_str == None:
+        if value_str is None:
             return None
 
         res, created = Document_attributesManager.get_or_create_attribute(attr_codes=attr_type__code, value_str=value_str)
@@ -436,7 +445,7 @@ class Item_lineManager(TreeAuditModelManager):
         request = DSRequest(request=request)
         res = 0
         with transaction.atomic():
-            for id, mode in request.get_tuple_ids():
+            for id, mode in request.get_olds_tuple_ids():
                 if mode == 'hide':
                     pass
                 elif mode == 'visible':
@@ -479,10 +488,10 @@ class Item_line(AuditModel):
 
     @property
     def qty(self):
-        if self.SPC_CLM_COUNT == None:
+        if self.SPC_CLM_COUNT is None:
             return None
 
-        if self.SPC_CLM_COUNT.value_int == None:
+        if self.SPC_CLM_COUNT.value_int is None:
             return StrToNumber(self.SPC_CLM_COUNT.value_str)
         return self.SPC_CLM_COUNT.value_int
 
