@@ -1,6 +1,7 @@
 import logging
 
 from bitfield import BitField
+from django.db.models import SmallIntegerField
 
 from clndr.models.calendars import Calendars
 from isc_common.fields.code_field import CodeField, CodeStrictField
@@ -41,6 +42,7 @@ class LocationsManager(CommonManagetWithLookUpFieldsManager):
             'deliting': record.deliting,
             'isWorkshop': record.props.isWorkshop,
             'props': record.props,
+            'level_grouping': record.level_grouping,
         }
         return DelProps(res)
 
@@ -52,6 +54,7 @@ class Locations(BaseRefHierarcy):
     code = CodeStrictField(unique=True)
     calendar = ForeignKeyProtect(Calendars, null=True, blank=True)
     color = CodeField()
+    level_grouping = SmallIntegerField(null=True, blank=True)
     props = LocationsManager.props()
 
     objects = LocationsManager()
