@@ -1,6 +1,6 @@
 import logging
 
-from django.db.models import BooleanField
+from django.db.models import BooleanField, SmallIntegerField
 from django.forms import model_to_dict
 
 from clndr.models.calendars import Calendars
@@ -50,6 +50,7 @@ class Locations_viewManager(CommonManagetWithLookUpFieldsManager):
             'deliting': record.deliting,
             'isWorkshop': record.props.isWorkshop,
             'props': record.props,
+            'level_grouping': record.level_grouping,
         }
         return DelProps(res)
 
@@ -59,9 +60,10 @@ class Locations_viewManager(CommonManagetWithLookUpFieldsManager):
 
 class Locations_view(BaseRefHierarcy):
     calendar = ForeignKeyProtect(Calendars, null=True, blank=True)
-    props = LocationsManager.props()
     color = CodeField()
     isFolder = BooleanField()
+    level_grouping = SmallIntegerField(null=True, blank=True)
+    props = LocationsManager.props()
     workshop = ForeignKeyProtect(Locations, null=True, blank=True)
 
     objects = Locations_viewManager()
