@@ -8,15 +8,16 @@ from kaf_pas.ckk.models.item_refs import Item_refs, Item_refsManager
 @JsonResponseWithException()
 def Item_refs_Fetch(request):
     _request = DSRequest(request)
+    data = Item_refs.objects. \
+        filter(). \
+        get_range_rows1(
+        request=request,
+        function=Item_refsManager.getRecord
+    )
     return JsonResponse(
         DSResponse(
             request=request,
-            data=Item_refs.objects.
-                filter().
-                get_range_rows1(
-                request=request,
-                function=Item_refsManager.getRecord
-            ),
+            data=data,
             status=RPCResponseConstant.statusSuccess).response)
 
 
