@@ -96,13 +96,13 @@ def Item_view_Variants_Fetch(request):
                             item['STMP_2'] = criterion.value
 
         elif isinstance(criterion, Criterion):
-            if criterion.fieldName == None:
+            if criterion.fieldName is None:
                 item_criterion = ItemCriterion(**criterion.dict)
 
-                if item_criterion.STMP_1__value_str != None:
+                if item_criterion.STMP_1__value_str is not None:
                     item['STMP_1'] = item_criterion.STMP_1__value_str
 
-                if item_criterion.STMP_2__value_str != None:
+                if item_criterion.STMP_2__value_str is not None:
                     item['STMP_2'] = item_criterion.STMP_2__value_str
 
             else:
@@ -133,6 +133,28 @@ def Item_view_Variants_Fetch(request):
             ),
             status=RPCResponseConstant.statusSuccess).response)
 
+@JsonResponseWithException()
+def Item_view_Teach_Fetch(request):
+    from kaf_pas.production.models.ready_2_launch_ext import Item_refs_Stack
+
+    _request = DSRequest(request=request)
+    data = _request.get_data()
+    items = list(Item.objects.filter(id=data.get('id')))
+
+    item_refs_Stack = Item_refs_Stack()
+    item_refs = [row[0] for row in item_refs_Stack.add_childs(id=[a.id for a in items])]
+
+    return JsonResponse(
+        DSResponse(
+            request=request,
+            data=Item_view_query().
+                filter(refs_id__in=item_refs).
+                get_range_rows_variant(
+                request=request,
+                function=Item_viewManager.getRecord,
+                distinct_field_names=('id',)
+            ),
+            status=RPCResponseConstant.statusSuccess).response)
 
 @JsonResponseWithException()
 def Item_view_4_idFetch(request):
@@ -174,7 +196,7 @@ def Item_view_Fetch2(request):
     data = _request.get_data()
 
     with transaction.atomic():
-        if data.get('launch_detail_id') == None:
+        if data.get('launch_detail_id') is None:
             return JsonResponse(
                 DSResponse(
                     request=request,
@@ -224,7 +246,7 @@ def Item_view_Fetch2(request):
                 request=request,
                 data=Item_operations_view.objects.raw(
                     raw_query=f'select * from {tmp_table_name}',
-                    function=Item_operations_viewManager.getRecord
+                    function=Item_operations_viewManager.getRecord1
                 ),
                 status=RPCResponseConstant.statusSuccess).response)
 
@@ -232,7 +254,7 @@ def Item_view_Fetch2(request):
 class ItemRef:
     def __init__(self, item_ref):
         self.child = item_ref.child.id
-        self.parent = item_ref.parent.id if item_ref.parent != None else item_ref.parent
+        self.parent = item_ref.parent.id if item_ref.parent is not None else item_ref.parent
         self.props = item_ref.props
 
     def __str__(self):
@@ -260,7 +282,7 @@ class UploadTmpTable:
         # print(f'level: {level}')
         for item_refs in Item_refs.objects.filter(child=child):
             self._rec_item_ref(item_ref=item_refs)
-            if item_refs.parent != None:
+            if item_refs.parent is not None:
                 self._rec_perents(child=item_refs.parent, level=level + 1)
                 # print(f'level: {level}')
 
@@ -287,7 +309,7 @@ class UploadDocumentTmpTable(UploadTmpTable):
         from kaf_pas.kd.models.lotsman_documents_hierarcy import Lotsman_documents_hierarcy
         from kaf_pas.ckk.models.item_document import Item_document
 
-        if self.lotsman_document_id == None:
+        if self.lotsman_document_id is None:
             for item in Item.objects.filter(document_id=self.id):
                 self._rec_perents(child=item, level=1)
 
@@ -312,7 +334,7 @@ def Item_view_Fetch3(request):
     _request = DSRequest(request=request)
     data = _request.get_data()
     record = data.get('record')
-    if record != None:
+    if record is not None:
         id = record.get('id')
     else:
         id = data.get('id')
@@ -344,16 +366,24 @@ def Item_view_Fetch3(request):
 @JsonResponseWithException(printing=False)
 def Item_view_Fetch4(request):
     from kaf_pas.production.models.ready_2_launch_ext import Item_refs_Stack
+    from kaf_pas.kd.models.documents_view import Documents_view
 
     _request = DSRequest(request=request)
     data = _request.get_data()
     record = data.get('record')
 
-    if record == None:
+    if record is None:
         id = data.get('id')
-        item = Item.objects.get(id=id)
-        STMP_1_id = item.STMP_1.id if item.STMP_1 else None
-        STMP_2_id = item.STMP_2.id if item.STMP_2 else None
+        if id is not None:
+            item = Item.objects.get(id=id)
+            STMP_1_id = item.STMP_1.id if item.STMP_1 else None
+            STMP_2_id = item.STMP_2.id if item.STMP_2 else None
+        else:
+            document_id = data.get('document_id')
+            item = Documents_view.objects.get(id=document_id)
+            STMP_1_id = item.STMP_1.id if item.STMP_1 else None
+            STMP_2_id = item.STMP_2.id if item.STMP_2 else None
+
     else:
         STMP_1_id = record.get('STMP_1_id')
         STMP_2_id = record.get('STMP_2_id')
@@ -411,7 +441,8 @@ def Item_view_Update(request):
 
 @JsonResponseWithException()
 def Item_view_Update1(request):
-    return JsonResponse(DSResponseUpdate(data=Item_operations_view.objects.updateFromRequest(request), status=RPCResponseConstant.statusSuccess).response)
+    return JsonResponse(DSResponseUpdate(data=Item.objects.updateFromRequest(request), status=RPCResponseConstant.statusSuccess).response)
+    # return JsonResponse(DSResponseUpdate(data=Item_operations_view.objects.updateFromRequest(request), status=RPCResponseConstant.statusSuccess).response)
 
 
 @JsonResponseWithException()
