@@ -1,7 +1,7 @@
 from isc_common.http.DSResponse import DSResponseUpdate, DSResponseAdd, DSResponse, JsonResponseWithException
 from isc_common.http.RPCResponse import RPCResponseConstant
 from isc_common.http.response import JsonResponse
-from kaf_pas.ckk.models.locations import Locations, LocationsManager
+from kaf_pas.ckk.models.locations import Locations
 from kaf_pas.ckk.models.locations_view import Locations_view, Locations_viewManager
 
 
