@@ -33,7 +33,7 @@ class DocumentManagerExt:
         from kaf_pas.kd.models.documents_thumb10 import Documents_thumb10
 
         document = item.document
-        if document != None:
+        if document is not None:
             for document_thumb in Documents_thumb.objects.filter(document=document):
                 Item_image_refs.objects.get_or_create(item=item, thumb=document_thumb)
 
@@ -45,7 +45,7 @@ class DocumentManagerExt:
         from kaf_pas.kd.models.documents_thumb import Documents_thumb
         from kaf_pas.kd.models.documents_thumb10 import Documents_thumb10
 
-        if lotsman_document != None:
+        if lotsman_document is not None:
             for document_thumb in Documents_thumb.objects.filter(lotsman_document_id=lotsman_document.id):
                 Item_image_refs.objects.get_or_create(item=item, thumb=document_thumb)
 
@@ -83,7 +83,7 @@ class DocumentManagerExt:
                 except Document_attributes_view.MultipleObjectsReturned:
                     STMP_2 = Document_attributes_view.objects.filter(document=document, attr_type__code='STMP_2')[0]
 
-                if STMP_1 != None or STMP_2 != None:
+                if STMP_1 is not None or STMP_2 is not None:
                     props = Item.props.relevant | Item.props.from_spw
 
                     version = ItemManager.get_verstion(
@@ -104,7 +104,7 @@ class DocumentManagerExt:
                     Item_refs.objects.create(parent_id=int(top_level.value), child=parent)
                     self.link_image_to_item(parent)
 
-                    if STMP_2 != None:
+                    if STMP_2 is not None:
                         self.rec_image_cwd(parent.id, delete_dbl_spaces(STMP_2.value_str))
 
                     query_spw = Document_attributes_view.objects.filter(document=document).order_by(*['position_in_document'])
@@ -118,7 +118,7 @@ class DocumentManagerExt:
                         SPC_CLM_MARK = delete_dbl_spaces(line_specification.get('SPC_CLM_MARK'))
                         SPC_CLM_MARK_ID = line_specification.get('SPC_CLM_MARK_ID')
 
-                        if SPC_CLM_NAME_ID != None or SPC_CLM_MARK_ID != None:
+                        if SPC_CLM_NAME_ID is not None or SPC_CLM_MARK_ID is not None:
                             if isinstance(SPC_CLM_MARK, str) and SPC_CLM_MARK.startswith('-') and isinstance(SPC_CLM_MARK_ID, int):
                                 _SPC_CLM_MARK = f'{SPC_CLM_MARK_old}{SPC_CLM_MARK}'
                                 for document_attribute in Document_attributes.objects.filter(id=SPC_CLM_MARK_ID):
@@ -144,12 +144,12 @@ class DocumentManagerExt:
                                 SPC_CLM_MARK_old = SPC_CLM_MARK
 
                             try:
-                                if SPC_CLM_MARK == None:
+                                if SPC_CLM_MARK is None:
                                     child = Item.objects.filter(
                                         STMP_1__value_str__delete_dbl_spaces=SPC_CLM_NAME,
                                         props=Item.props.relevant
                                     )[0]
-                                elif SPC_CLM_NAME == None:
+                                elif SPC_CLM_NAME is None:
                                     child = Item.objects.filter(
                                         STMP_2__value_str__delete_dbl_spaces=SPC_CLM_MARK,
                                         props=Item.props.relevant
@@ -238,7 +238,7 @@ class DocumentManagerExt:
                 except Document_attributes_view.MultipleObjectsReturned:
                     STMP_2 = Document_attributes_view.objects.filter(document=document, attr_type__code='STMP_2')[0]
 
-                if STMP_1 != None or STMP_2 != None:
+                if STMP_1 is not None or STMP_2 is not None:
 
                     props = Item.props.relevant | Item.props.from_cdw
                     version = ItemManager.get_verstion(
