@@ -28,7 +28,7 @@ class Lotsman_documents_hierarcy_viewQuerySet(AuditQuerySet):
             where document_id = %s''', [kwargs.get('document_id')])
             level_min = cursor.fetchone()[0]
 
-            if level_min == None:
+            if level_min is None:
                 level_min = 1
 
             cursor.execute(f'''SELECT 'SELECT case when a.level = {level_min} then null
@@ -48,7 +48,7 @@ class Lotsman_documents_hierarcy_viewQuerySet(AuditQuerySet):
             cursor.execute(sqlstmt)
 
             parent_str = 'parent_id is null'
-            if kwargs.get('parent_id') != None:
+            if kwargs.get('parent_id') is not None:
                 parent_str = f'''parent_id={kwargs.get('parent_id')}'''
 
             sqlstmt = f'''select * from {m_view_recurs_doc_name}
@@ -77,7 +77,7 @@ class Lotsman_documents_hierarcy_viewManager(AuditManager):
 
     @staticmethod
     def getIcon(record):
-        if record.attr_name != None:
+        if record.attr_name is not None:
             _section = record.attr_name.lower()
             if _section == 'документация':
                 return 'documentation.png'
@@ -259,22 +259,22 @@ class Lotsman_documents_hierarcy_view(AuditModel):
         return self.__str__()
 
     def get_mat(selfname, name, doc):
-        if name != None and doc != None:
+        if name is not None and doc is not None:
             return f'{name}/{doc}'
-        elif name != None and doc == None:
+        elif name is not None and doc is None:
             return name
-        elif name == None and doc != None:
+        elif name is None and doc is not None:
             return doc
         else:
             return None
 
     @property
     def item_name(self):
-        if self.SPC_CLM_NAME != None and self.SPC_CLM_MARK != None:
+        if self.SPC_CLM_NAME is not None and self.SPC_CLM_MARK is not None:
             return f'{get_NoneStr(self.SPC_CLM_NAME.value_str)}: {get_NoneStr(self.SPC_CLM_MARK.value_str)}'
-        elif self.SPC_CLM_NAME == None and self.SPC_CLM_MARK != None:
+        elif self.SPC_CLM_NAME is None and self.SPC_CLM_MARK is not None:
             return get_NoneStr(self.SPC_CLM_MARK.value_str)
-        elif self.SPC_CLM_NAME != None and self.SPC_CLM_MARK == None:
+        elif self.SPC_CLM_NAME is not None and self.SPC_CLM_MARK is None:
             return get_NoneStr(self.SPC_CLM_NAME.value_str)
         else:
             return 'Неизвестен'
