@@ -67,7 +67,7 @@ class UploadesManager(AuditManager):
         from kaf_pas.kd.models.lotsman_documents_hierarcy_refs import Lotsman_documents_hierarcy_refs
         from kaf_pas.kd.models.uploades_documents import Uploades_documents
         from kaf_pas.kd.models.uploades_log import Uploades_log
-        from kaf_pas.ckk.models.tmp_item_refs import Tmp_Item_refsManager
+        # from kaf_pas.ckk.models.tmp_item_refs import Tmp_Item_refsManager
 
         # eventStack = EventStack()
 
@@ -77,7 +77,7 @@ class UploadesManager(AuditManager):
 
         settings.LOCKS.acquire(key)
 
-        if document_id == None:
+        if document_id is None:
             for upload_document in Uploades_documents.objects.filter(upload_id=id):
                 lotsman_cnt += Lotsman_documents_hierarcy.objects.filter(document=upload_document.document).count()
         else:
@@ -85,25 +85,25 @@ class UploadesManager(AuditManager):
 
         upload = Uploades.objects.get(id=id)
 
-        if document_id != None:
+        if document_id is not None:
             upload_document = Uploades_documents.objects.get(id=document_id)
 
-        qty = Uploades_documents.objects.filter(upload_id=id).count() + lotsman_cnt if document_id == None else 1 + lotsman_cnt
+        qty = Uploades_documents.objects.filter(upload_id=id).count() + lotsman_cnt if document_id is None else 1 + lotsman_cnt
         with managed_progress(
                 qty=qty,
                 id=f'Remove_upload_{id}',
                 user=user,
-                message=f'Удаление закачки: {upload.path.drived_absolute_path} от {DateTimeToStr(upload.lastmodified)}' if document_id == None else f'Удаление документа: {upload_document.document.file_document}',
+                message=f'Удаление закачки: {upload.path.drived_absolute_path} от {DateTimeToStr(upload.lastmodified)}' if document_id is None else f'Удаление документа: {upload_document.document.file_document}',
                 title='Выполнено',
                 props=TurnBitOn(0, 0)
         ) as progress:
             try:
                 res = 0
-                Tmp_Item_refsManager.create()
+                # Tmp_Item_refsManager.create()
                 with transaction.atomic():
                     continue_cnt = 0
 
-                    if document_id == None:
+                    if document_id is None:
                         upload_query = Uploades_documents.objects.select_for_update().filter(upload_id=id)
                     else:
                         upload_query = Uploades_documents.objects.select_for_update().filter(id=document_id)
@@ -197,7 +197,7 @@ class UploadesManager(AuditManager):
                     if continue_cnt == 0:
                         deleted = Uploades_log.objects.filter(upload_id=id).delete()
                         logger.debug(f'deleted: {deleted}')
-                        if document_id == None:
+                        if document_id is None:
                             res += Uploades.objects.filter(id=id).delete()[0]
                             # eventStack.EVENTS_DOWNLOAD_CONFIRM.send_message(message=progress.progresses.label_contents)
 
