@@ -1,4 +1,4 @@
-from isc_common.http.DSResponse import DSResponseUpdate, DSResponseAdd, DSResponse, JsonResponseWithException
+from isc_common.http.DSResponse import DSResponseUpdate, DSResponse, JsonResponseWithException
 from isc_common.http.RPCResponse import RPCResponseConstant
 from isc_common.http.response import JsonResponse
 from kaf_pas.kd.models.spw_attrs import Spw_attrs, Spw_attrsManager
@@ -17,6 +17,7 @@ def Spw_attrs_Fetch(request):
             ),
             status=RPCResponseConstant.statusSuccess).response)
 
+
 @JsonResponseWithException()
 def Spw_attrs_Update(request):
     return JsonResponse(DSResponseUpdate(data=Spw_attrs.objects.updateFromRequest(request), status=RPCResponseConstant.statusSuccess).response)
@@ -30,4 +31,3 @@ def Spw_attrs_Update(request):
 @JsonResponseWithException()
 def Spw_attrs_Info(request):
     return JsonResponse(DSResponse(request=request, data=Spw_attrs.objects.get_queryset().get_info(request=request), status=RPCResponseConstant.statusSuccess).response)
-
