@@ -26,14 +26,14 @@ class Launch_itemsManager(Manager):
     def find_item(item, launch=None):
 
         items = ItemManager.find_item(item)
-        if launch != None:
+        if launch is not None:
             try:
-                return Launch_items.objects.filter(launch=launch, item__in=items).exclude(location=F('wlocation')).order_by('num')[0]
+                return Launch_items.objects.filter(launch=launch, item__in=items).exclude(location=F('wlocation')).order_by('num')
             except IndexError:
                 return None
         else:
             try:
-                return Launch_items.objects.filter(item__in=items).exclude(location=F('wlocation')).order_by('num')[0]
+                return Launch_items.objects.filter(item__in=items).exclude(location=F('wlocation')).order_by('num')
             except IndexError:
                 return None
 
