@@ -1,11 +1,13 @@
 import logging
 
+from django.db import transaction
 from django.db.models import TextField
 
 from isc_common import delAttr
 from isc_common.fields.code_field import JSONFieldIVC
 from isc_common.fields.related import ForeignKeyCascade
 from isc_common.http.DSRequest import DSRequest
+from isc_common.json import StrToJson
 from isc_common.models.audit import AuditModel, AuditManager
 from kaf_pas.ckk.models.item import Item
 from kaf_pas.planing.models.operations import BaseOperationQuerySet
@@ -40,6 +42,15 @@ class Operation_item_addManager(AuditManager):
     def get_queryset(self):
         return Operation_item_addQuerySet(self.model, using=self._db)
 
+    @staticmethod
+    def re_fill_item_full_name_obj():
+        with transaction.atomic():
+            for operation_item_add in Operation_item_add.objects.all():
+                item_full_name_obj = operation_item_add.item_full_name_obj
+                if isinstance(item_full_name_obj, str):
+                    operation_item_add.item_full_name_obj = StrToJson(operation_item_add.item_full_name_obj)
+                    operation_item_add.save()
+
 
 class Operation_item_add(AuditModel):
     item = ForeignKeyCascade(Item)
