@@ -24,8 +24,8 @@ class Operation_refsQuerySet(TreeAuditModelQuerySet):
         refs = ORF_Wrapper(**kwargs)
 
         if not kwargs.get('enable_parent_None'):
-            if refs.parent == None and refs.parent_id == None:
-                raise Exception('Запись parent == None Запрещена')
+            if refs.parent is None and refs.parent_id is None:
+                raise Exception('Запись parent is None Запрещена')
         else:
             delAttr(kwargs, 'enable_parent_None')
 
@@ -47,7 +47,7 @@ class Operation_refsManager(TreeAuditModelManager):
         logger.debug(f'operation_refs: {operation_refs}')
         logger.debug('operation_refs: ==================================================\n')
 
-        if props != None:
+        if props is not None:
             query = Operation_refs.objects.filter(child=operation_refs.parent, props=props)
         else:
             query = Operation_refs.objects.filter(child=operation_refs.parent)
@@ -70,6 +70,7 @@ class Operation_refsManager(TreeAuditModelManager):
             ('product_order_routing', 'Связи в блоке задания на производство'),  # 2-4
             ('product_making', 'Связи выпуска'),  # 3-8
             ('product_making_block', 'Блок операций выпуска, удаляется как одно целое'),  # 4-16
+            ('for_grouped', 'Cгруппировано в задании на производство'),  # 5-32
         ), default=0, db_index=True)
 
     @staticmethod
