@@ -1,19 +1,18 @@
 import logging
 
-from django.db.models import CheckConstraint, UniqueConstraint, F, Q
+from django.db.models import UniqueConstraint, Q
 
 from isc_common.fields.related import ForeignKeyProtect, ForeignKeyCascade
-from isc_common.models.audit import AuditManager, AuditModel, AuditQuerySet
+from isc_common.models.audit import AuditManager, AuditModel
 from kaf_pas.ckk.models.locations import Locations
-from kaf_pas.planing.models.operations import Operations
+from kaf_pas.planing.models.operations import Operations, BaseOperationQuerySet
 from kaf_pas.production.models.resource import Resource
 
 logger = logging.getLogger(__name__)
 
 
-class Operation_resourcesQuerySet(AuditQuerySet):
-    def create(self, **kwargs):
-        return super().create(**kwargs)
+class Operation_resourcesQuerySet(BaseOperationQuerySet):
+    pass
 
 
 class Operation_resourcesManager(AuditManager):
@@ -33,8 +32,9 @@ class Operation_resourcesManager(AuditManager):
 
 class Operation_resources(AuditModel):
     operation = ForeignKeyCascade(Operations, related_name='planing_operation_res')
-    resource = ForeignKeyProtect(Resource, related_name='planing_resource_res')
     location_fin = ForeignKeyProtect(Locations, related_name='planing_location_fin_res', null=True, blank=True)
+    resource = ForeignKeyProtect(Resource, related_name='planing_resource_res')
+    resource_fin = ForeignKeyProtect(Resource, related_name='planing_resource_fin_res', null=True, blank=True)
 
     objects = Operation_resourcesManager()
 
@@ -50,6 +50,9 @@ class Operation_resources(AuditModel):
     class Meta:
         verbose_name = 'Кросс таблица'
         constraints = [
-            UniqueConstraint(fields=['operation', 'resource'], condition=Q(location_fin=None), name='Operation_resources_unique_constraint_01'),
-            UniqueConstraint(fields=['location_fin', 'operation', 'resource'], name='Operation_resources_unique_constraint_11'),
+            UniqueConstraint(fields=['operation', 'resource'], condition=Q(location_fin=None) & Q(resource_fin=None), name='Operation_resources_unique_constraint_planing_0'),
+            UniqueConstraint(fields=['operation', 'resource', 'resource_fin'], condition=Q(location_fin=None), name='Operation_resources_unique_constraint_planing_1'),
+            UniqueConstraint(fields=['location_fin', 'operation', 'resource'], condition=Q(resource_fin=None), name='Operation_resources_unique_constraint_planing_2'),
+            UniqueConstraint(fields=['location_fin', 'operation', 'resource', 'resource_fin'], name='Operation_resources_unique_constraint_planing_3'),
+
         ]
