@@ -15,7 +15,7 @@ from isc_common.http.DSRequest import DSRequest
 from isc_common.managers.common_managet_with_lookup_fields import CommonManagetWithLookUpFieldsManager, CommonManagetWithLookUpFieldsQuerySet
 from isc_common.models.audit import AuditQuerySet
 from isc_common.models.base_ref import Hierarcy, BaseRefQuerySet
-from isc_common.number import DelProps, model_2_dict, flen
+from isc_common.number import DelProps, model_2_dict
 from isc_common.progress import managed_progress, ProgressDroped, progress_deleted
 from kaf_pas.planing.models.operation_types import Operation_types
 from kaf_pas.planing.models.status_operation_types import Status_operation_types
@@ -39,7 +39,7 @@ class OperationsQuerySet(BaseRefQuerySet, CommonManagetWithLookUpFieldsQuerySet,
     def create(self, **kwargs):
         from isc_common.seq import get_deq_next_value
 
-        if kwargs.get('num') == None:
+        if kwargs.get('num') is None:
             setAttr(kwargs, 'num', str(get_deq_next_value('production_order_num')))
 
         with transaction.atomic():
@@ -98,7 +98,7 @@ class OperationsManager(CommonManagetWithLookUpFieldsManager):
                                                       where opertype_id in  ({opertypes})
                                                      order by level desc'''
 
-        count = Operation_refs.objects.get_descendants_count(id=operation.id, sql_text=sql_text if opertypes != None else None)
+        count = Operation_refs.objects.get_descendants_count(id=operation.id, sql_text=sql_text if opertypes is not None else None)
         operations = set()
 
         if count > 0:
@@ -113,7 +113,7 @@ class OperationsManager(CommonManagetWithLookUpFieldsManager):
                 # with transaction.atomic():
                 for operation_refs in Operation_refs.objects.get_descendants(
                         id=operation.id,
-                        sql_text=sql_text if opertypes != None else None):
+                        sql_text=sql_text if opertypes is not None else None):
                     if not soft_delete:
                         Operation_refs.objects.filter(id=operation_refs.id).delete()
                         operations.add(operation_refs.child.id)
@@ -152,13 +152,13 @@ class OperationsManager(CommonManagetWithLookUpFieldsManager):
 
         if location_id:
             resource = None
-            if resource_id == None:
+            if resource_id is None:
                 try:
                     resource = Resource.objects.get(code='none', location_id=location_id)
                 except Resource.DoesNotExist:
                     resource = Resource.objects.create(code='node', name='Не определен', location_id=location_id, calendar=CalendarsManager.get_default())
 
-            if resource == None:
+            if resource is None:
                 resource = Resource.objects.get(id=resource_id)
                 if resource.location_id != location_id:
                     resource = Resource.objects.create(location_id=location_id, calendar=resource.calendar)
@@ -394,8 +394,8 @@ def pre_delete(sender, **kwargs):
 
     instance = kwargs.get('instance')
     if instance.opertype == settings.OPERS_TYPES_STACK.PRODUCTION_TASK:
-        if flen(instance.minus_values) > 0:
-            raise Exception(f'Удаление невозможно, есть связанные выпуски.')
+        # if flen(instance.minus_values) > 0:
+        #     raise Exception(f'Удаление невозможно, есть связанные выпуски.')
 
         Production_orderManager.delete_redundant_planing_production_order_table(instance)
         Production_orderManager.refresh_all(
