@@ -2,6 +2,7 @@ import logging
 
 from isc_common import Stack
 from isc_common.common import new
+from isc_common.json import StrToJson
 
 logger = logging.getLogger(__name__)
 
@@ -320,7 +321,7 @@ class Routing_ext:
                                     logger.debug(f'qty: {qty}')
 
                                 elif mode == 'parent':
-                                    if parent_id != None:
+                                    if parent_id is not None:
                                         child_id = parent_id
 
                                 if not routed_items.exists(lambda child_item: child_item.item_id == child_id):
@@ -349,11 +350,16 @@ class Routing_ext:
                                             )
                                             logger.debug(f'Created operation_item :  {operation_item}')
 
+                                            if isinstance(item_full_name_obj, str):
+                                                item_full_name_obj = StrToJson(item_full_name_obj)
+
                                             operation_item_add, created = Operation_item_add.objects.get_or_create(
                                                 item=launch_operations_item.item,
                                                 launch=launch_operations_item.launch,
                                                 item_full_name=item_full_name,
-                                                defaults=dict(item_full_name_obj=item_full_name_obj)
+                                                defaults=dict(
+                                                    item_full_name_obj=item_full_name_obj
+                                                )
                                             )
                                             logger.debug(f'Created operation_item_add :  {operation_item_add}')
 
@@ -384,7 +390,7 @@ class Routing_ext:
                                             operation_value = Operation_value.objects.create(
                                                 operation=outcome_operation,
                                                 value=qty_per_one,
-                                                edizm_id=edizm_id if edizm_id != None else edizm_shtuka.id,
+                                                edizm_id=edizm_id if edizm_id is not None else edizm_shtuka.id,
                                                 props=Operation_value.props.perone
                                             )
                                             logger.debug(f'Created operation_value :  {operation_value}')
@@ -392,12 +398,12 @@ class Routing_ext:
                                             operation_value = Operation_value.objects.create(
                                                 operation=outcome_operation,
                                                 value=qty,
-                                                edizm_id=edizm_id if edizm_id != None else edizm_shtuka.id,
+                                                edizm_id=edizm_id if edizm_id is not None else edizm_shtuka.id,
                                             )
                                             logger.debug(f'Created operation_value :  {operation_value}')
 
                                             for launch_operation_material in Launch_operations_material.objects.filter(launch_operationitem=launch_operations_item):
-                                                if launch_operation_material.operation_material != None:
+                                                if launch_operation_material.operation_material is not None:
                                                     operation_material, _ = Operation_material.objects.get_or_create(
                                                         operation=outcome_operation,
                                                         material=launch_operation_material.material,
@@ -426,7 +432,7 @@ class Routing_ext:
                                                 )
                                                 logger.debug(f'Created operation_resources :  {operation_resources}')
 
-                                            if income_operation == None:
+                                            if income_operation is None:
                                                 first_operation = outcome_operation
 
                                             operation_refs = Operation_refs.objects.create(
@@ -470,7 +476,7 @@ class Routing_ext:
                         for row in rows:
                             id, parent_id, child_id, launch_id, qty, replication_factor, qty_per_one, edizm_id, level, item_full_name, item_full_name_obj = row
                             try:
-                                if parent_id == None:
+                                if parent_id is None:
                                     parent_id = child_id
                                 parent_item = routed_items.find_one(lambda item: item.item_id == parent_id)
                             except StackElementNotExist:
@@ -631,20 +637,20 @@ class Routing_ext:
         from kaf_pas.planing.models.operation_launch_item import Operation_launch_item
         from kaf_pas.production.models.launch_operations_item import Launch_operations_item
 
-        if num != None and old_num != None:
+        if num is not None and old_num is not None:
             raise Exception('Оба параметра не могут быть не пустыми')
 
-        if num == None and old_num == None:
+        if num is None and old_num is None:
             raise Exception('Оба параметра не могут быть пустыми')
 
-        if num != None:
+        if num is not None:
             launch_operations_item_query = Launch_operations_item.objects.filter(
                 launch=launch,
                 item=item,
                 num=num,
                 deleted_at=None
             )
-        elif old_num != None:
+        elif old_num is not None:
             launch_operations_item_query = Launch_operations_item.objects.filter(
                 launch=launch,
                 item=item,
@@ -678,7 +684,7 @@ class Routing_ext:
                     pass
                     logger.debug(f'created new_operation_ref.parent: {operation_ref.parent.id if operation_ref.parent else None}, new_operation_ref.child: {operation_ref.child.id}')
                 else:
-                    if operation_ref.deleted_at != None:
+                    if operation_ref.deleted_at is not None:
                         operation_ref.soft_restore()
 
     def change_childs(self, new_childs, operation, user):
@@ -696,14 +702,14 @@ class Routing_ext:
                     pass
                     logger.debug(f'created new_operation_ref.parent: {operation_ref.parent.id if operation_ref.parent else None}, new_operation_ref.child: {operation_ref.child.id}')
                 else:
-                    if operation_ref.deleted_at != None:
+                    if operation_ref.deleted_at is not None:
                         operation_ref.soft_restore()
 
     def update_routing(self, data, old_data, updated_launch_operations_items: Stack, user, key=None):
         from kaf_pas.planing.models.operation_launch_item import Operation_launch_item
 
         logger.debug(f'num: {data.production_operation_num}')
-        if old_data != None:
+        if old_data is not None:
             logger.debug(f'old_num: {old_data.production_operation_num}')
 
         for launch_id in list(set([a.launch.id for a in updated_launch_operations_items])):
@@ -743,7 +749,7 @@ class Routing_ext:
                     been_is_created = updated_launch_operations_item.is_created
 
                 if updated_launch_operations_item.num == 1:
-                    if old_data != None and data.production_operation_num < old_data.production_operation_num:
+                    if old_data is not None and data.production_operation_num < old_data.production_operation_num:
                         prev_num_operation = self.get_num_operation(
                             launch=updated_launch_operations_item.launch,
                             item=updated_launch_operations_item.item,
@@ -753,7 +759,7 @@ class Routing_ext:
                         prev_num_operation = self.get_num_operation(
                             launch=updated_launch_operations_item.launch,
                             item=updated_launch_operations_item.item,
-                            old_num=old_data.production_operation_num if old_data != None else updated_launch_operations_item.num
+                            old_num=old_data.production_operation_num if old_data is not None else updated_launch_operations_item.num
                         )
                     parents = self.get_parents(operation=prev_num_operation)
                 else:
