@@ -28,14 +28,14 @@ class Launch_operations_itemQuerySet(CommonManagetWithLookUpFieldsQuerySet):
     def create(self, **kwargs):
         self._check_ed_izm_qty(**kwargs)
 
-        if kwargs.get('props') == None:
+        if kwargs.get('props') is None:
             setAttr(kwargs, 'props', Launch_operations_item.props.created)
         return super().create(**kwargs)
 
     def update(self, **kwargs):
         self._check_ed_izm_qty(**kwargs)
 
-        if kwargs.get('props') == None:
+        if kwargs.get('props') is None:
             setAttr(kwargs, 'props', Launch_operations_item.props.updated)
         return super().update(**kwargs)
 
@@ -44,9 +44,9 @@ class Launch_operations_itemQuerySet(CommonManagetWithLookUpFieldsQuerySet):
         data = request.json.get('data')
 
         launch_id = data.get('launch_id')
-        if launch_id != None:
+        if launch_id is not None:
             parent = Launches.objects.get(id=launch_id).parent
-            if parent == None:
+            if parent is None:
                 launch_id = [launch.id for launch in Launches.objects.filter(parent_id=launch_id)]
                 setAttr(data, 'launch_id', launch_id)
                 request.set_data(data=data)
@@ -210,7 +210,7 @@ class Launch_operations_itemManager(CommonManagetWithLookUpFieldsManager):
                     super().filter(id=id).soft_delete()
                 elif mode == 'visible':
                     super().filter(id=id).soft_restore()
-                elif mode == None:
+                elif mode is None:
                     Launch_item_viewManager.check_launch(launch=Launch_operations_item.objects.get(id=id).launch)
                     qty, _ = super().filter(id=id).delete()
                 else:
