@@ -59,7 +59,7 @@ class Launches_ext:
             if len(parent_items) == 1:
                 qty = parent_items[0][2]
             elif len(parent_items) == 0:
-                if qty == None:
+                if qty is None:
                     raise StackElementNotExist(blinkString(f'Не удалось получить количество для : {get_full_path}', color=red, bold=True))
             else:
                 parent_item = list(reversed(sorted(parent_items, key=lambda x: x[0])))
@@ -74,7 +74,7 @@ class Launches_ext:
         if _str == 'null':
             _str = None
 
-        if _str != None:
+        if _str is not None:
             if _str.find(',') != -1:
                 try:
                     str1 = _str.replace(',', '.')
@@ -121,7 +121,7 @@ class Launches_ext:
         else:
             res = item_line.SPC_CLM_COUNT
 
-        if res == None and item_line.section != 'Документация':
+        if res is None and item_line.section != 'Документация':
             raise Exception(blinkString(f'Для: {get_full_path} count == 0', color='red', bold=True, blink=False))
 
         # settings.LOCKS.release(key)
@@ -170,7 +170,7 @@ class Launches_ext:
             for operation_material in operation_material_query:
                 # start_time = time.clock()
                 # 'launch_operationitem', 'material', 'material_askon'
-                if operation_material.material != None or operation_material.material_askon != None:
+                if operation_material.material is not None or operation_material.material_askon is not None:
                     launch_operations_material, created = Launch_operations_material.objects.get_or_create(
                         launch_operationitem=launch_operations_item,
                         material=operation_material.material,
@@ -195,17 +195,17 @@ class Launches_ext:
                 exception_not_location()
 
             for operation_resources in operation_resources_query:
-                if operation_resources.location == None:
+                if operation_resources.location is None:
                     exception_not_location()
 
-                if operation_resources.resource == None:
+                if operation_resources.resource is None:
                     operation_resources.resource, created = settings.OPERS_STACK.NOT_UNDEFINED_WORKSHOP(operation_resources.location)
 
-                if operation_resources.resource_fin == None:
+                if operation_resources.resource_fin is None:
                     operation_resources.resource_fin, created = settings.OPERS_STACK.NOT_UNDEFINED_WORKSHOP(operation_resources.location_fin)
 
                 if operations_item.operation.is_transportation:
-                    if operation_resources.resource_fin == None and operation_resources.location_fin == None:
+                    if operation_resources.resource_fin is None and operation_resources.location_fin is None:
                         raise Exception(f'''<b>Для : {get_full_path}</b>  {blinkString(text=f'в операции {operations_item.operation.full_name} не задано конечное местоположение. Запустите анализатор готовности к запуску.', blink=False, color='red', bold=True)}''')
 
                 launch_operation_resource, created = Launch_operation_resources.objects.get_or_create(
@@ -247,8 +247,8 @@ class Launches_ext:
 
                 for operations_item in operations_item_query:
                     try:
-                        if (operations_item.ed_izm != None and operations_item.qty == None) or \
-                                (operations_item.ed_izm == None and operations_item.qty != None):
+                        if (operations_item.ed_izm is not None and operations_item.qty is None) or \
+                                (operations_item.ed_izm is None and operations_item.qty is not None):
                             operations_item.ed_izm = None
                             operations_item.qty = None
                             operations_item.save()
@@ -282,14 +282,14 @@ class Launches_ext:
         edizm_shtuka = Ed_izm.objects.get(code='шт')
 
         if mode == 'update':
-            if demand != None:
+            if demand is not None:
                 item_query = Launches.objects.filter(demand=demand, status__code='formirovanie')
                 item_count = item_query.count()
                 if item_count > 0:
                     settings.LOCKS.release(key)
                     raise Exception(f'{demand.code} от {DateToStr(demand.lastmodified)} уже включен в данный запуск.')
 
-        if demand != None:
+        if demand is not None:
             cnt = Launches.objects.filter(demand=demand).count() + 1
             child_code = f'{demand.code}/{cnt}'
         else:
@@ -299,13 +299,19 @@ class Launches_ext:
         logger.debug(f'cnt: {cnt}')
         # logger.debug(f'child_code: {child_code}')
 
-        where_clause = f'where is_bit_on(props::integer, 0) = true and is_bit_on(props::integer, 1) = true and parent_id != {p_id}'
-        if demand != None:
+        if demand is not None:
+            where_clause = f'where is_bit_on(props, 0) = true \n' \
+                           f'-- and is_bit_on(props, 1) = true \n' \
+                           f'and parent_id != {p_id}'
+
             cntAll = Item_refs.objects.get_descendants_count(
                 id=demand.precent_item.item.id,
                 where_clause=where_clause,
             )
         else:
+            where_clause = f'where is_bit_on(props, 0) = true \n' \
+                           f'-- and is_bit_on(props, 1) = true \n'
+
             cntAll = Item_refs.objects.get_descendants_count(
                 id=item.id,
                 where_clause=where_clause,
@@ -330,13 +336,13 @@ class Launches_ext:
             settings.LOCKS.release(key)
             raise Exception(f'Unknown mode: {mode}')
 
-        if demand != None:
+        if demand is not None:
             message = blinkString(f'Формирование производственной спецификации: <br>Запуск № {code}, <br>Заказ № {demand.code} от {DateToStr(demand.date)} ({cntAll} позиций.)', bold=True, blink=False)
         else:
             message = blinkString(f'Формирование производственной спецификации: <br>Запуск № {child_code}, от {DateToStr(date)} <br>Изделие: {item.item_name} ({cntAll} позиций.)</pre>', bold=True, blink=False)
 
         with managed_progress(
-                id=f'demand_{demand.id}_{user.id}' if demand != None else f'demand_{item.id}_{user.id}',
+                id=f'demand_{demand.id}_{user.id}' if demand is not None else f'demand_{item.id}_{user.id}',
                 qty=cntAll,
                 user=user.id,
                 message=message,
@@ -350,10 +356,10 @@ class Launches_ext:
 
                 progress.except_func = except_func
 
-                qty = demand.qty if demand != None else qty
+                qty = demand.qty if demand is not None else qty
 
                 if mode == 'add':
-                    if parentlaunch == None:
+                    if parentlaunch is None:
                         parentlaunch = Launches.objects.create(
                             date=date,
                             code=code,
@@ -365,8 +371,8 @@ class Launches_ext:
                     parent=parentlaunch,
                     code=child_code,
                     date=date,
-                    demand=demand if demand != None else None,
-                    item=item if item != None else demand.precent_item.item,
+                    demand=demand if demand is not None else None,
+                    item=item if item is not None else demand.precent_item.item,
                     description=description,
                     qty=qty,
                     status=settings.PROD_OPERS_STACK.FORMIROVANIE
@@ -374,7 +380,9 @@ class Launches_ext:
 
                 items_refs_stack = Item_refs_Stack()
                 items_refs_qty_stack = Stack()
-                if demand != None:
+                items_refs_not_used = Stack()
+
+                if demand is not None:
                     items_refs_stack.add_parents(id=demand.precent_item.item.id)
                     item_ref_query = Item_refs.objects.get_descendants(
                         id=demand.precent_item.item.id,
@@ -390,46 +398,53 @@ class Launches_ext:
                     )
 
                 for item_ref in item_ref_query:
-                    if ~item_ref.props.used:
-                        settings.LOCKS.release(key)
+                    if item_ref.props.used.is_set == False or items_refs_not_used.exists(lambda x: item_ref.parent.id):
+                        items_refs_not_used.push(item_ref.child.id)
                         continue
 
                     items_refs_stack.push(item_ref)
+                    item_line = None
 
                     try:
                         item_line = Item_line.objects.get(parent=item_ref.parent, child=item_ref.child)
                         # logger.debug(f'item_line: {item_line}')
 
                     except Item_line.DoesNotExist:
-                        settings.LOCKS.release(key)
-                        raise Exception(blinkString(text=f'Для : PARENT_ID: {item_ref.parent.id if item_ref.parent else None} CHILD_ID: {item_ref.child.id} {items_refs_stack.get_full_path} не найдена строка детализации.', bold=True, blink=False))
+                        if demand is not None:
+                            settings.LOCKS.release(key)
+                            raise Exception(blinkString(text=f'Для : PARENT_ID: {item_ref.parent.id if item_ref.parent else None} CHILD_ID: {item_ref.child.id} {items_refs_stack.get_full_path} не найдена строка детализации.', bold=True, blink=False))
 
-                    count = self.get_count(
-                        item_line=item_line,
-                        qty=demand.qty if demand != None else qty,
-                        level=item_ref.level,
-                        get_full_path=items_refs_stack.get_full_path,
-                        items_refs_qty_stack=items_refs_qty_stack
-                    )
+                    if item_line is not None:
+                        count = self.get_count(
+                            item_line=item_line,
+                            qty=demand.qty if demand is not None else qty,
+                            level=item_ref.level,
+                            get_full_path=items_refs_stack.get_full_path,
+                            items_refs_qty_stack=items_refs_qty_stack
+                        )
 
-                    _count_per_one = StrToNumber(item_line.SPC_CLM_COUNT.value_str) if count != None and item_line.section != 'Документация' else 0
-                    _count = StrToNumber(count.value_str) if count != None and item_line.section != 'Документация' else 0
+                        _count_per_one = StrToNumber(item_line.SPC_CLM_COUNT.value_str) if count is not None and item_line.section != 'Документация' else 0
+                        _count = StrToNumber(count.value_str) if count is not None and item_line.section != 'Документация' else 0
 
-                    if items_refs_qty_stack.exists(lambda x: x[0] == item_ref.level and x[1] == item_ref.child.id) == False:
-                        items_refs_qty_stack.push((item_ref.level, item_ref.child.id, _count))
+                        if items_refs_qty_stack.exists(lambda x: x[0] == item_ref.level and x[1] == item_ref.child.id) == False:
+                            items_refs_qty_stack.push((item_ref.level, item_ref.child.id, _count))
+                    else:
+                        _count = qty
+                        _count_per_one = 1
 
                     # start_time = time.clock()
                     logger.debug('//////////////////////////')
                     logger.debug(f'parent: {item_ref.parent.item_name if item_ref.parent else None}, child: {item_ref.child.item_name}, qrt: {_count}, qty_per_one: {_count_per_one}')
                     logger.debug('//////////////////////////')
+
                     launch_item_refs, created = Launch_item_refs.objects.get_or_create(
                         child=item_ref.child,
                         parent=item_ref.parent if item_ref.level != 1 else None,
                         launch=launch,
-                        qty=_count,
-                        qty_per_one=_count_per_one,
                         defaults=dict(
                             item_refs=item_ref,
+                            qty=_count,
+                            qty_per_one=_count_per_one,
                             item_full_name=items_refs_stack.get_full_path,
                             item_full_name_obj=items_refs_stack.get_full_path_obj
                         )
@@ -447,45 +462,49 @@ class Launches_ext:
 
                         # start_time = time.clock()
 
-                    edizm = item_line.edizm if item_line.edizm else edizm_shtuka
+                    edizm = item_line.edizm if item_line is not None and item_line.edizm else edizm_shtuka
 
-                    launch_item_line, created = Launch_item_line.objects.get_or_create(
-                        child=item_line.child,
-                        parent=item_line.parent,
-                        launch=launch,
+                    launch_item_line = None
 
-                        defaults=dict(
-                            item_line=item_line,
-                            SPC_CLM_FORMAT=item_line.SPC_CLM_FORMAT,
-                            SPC_CLM_ZONE=item_line.SPC_CLM_ZONE,
-                            SPC_CLM_POS=item_line.SPC_CLM_POS,
-                            SPC_CLM_MARK=item_line.SPC_CLM_MARK,
-                            SPC_CLM_NAME=item_line.SPC_CLM_NAME,
-                            SPC_CLM_COUNT=count,
-                            SPC_CLM_NOTE=item_line.SPC_CLM_NOTE,
-                            SPC_CLM_MASSA=item_line.SPC_CLM_MASSA,
-                            SPC_CLM_MATERIAL=item_line.SPC_CLM_MATERIAL,
-                            SPC_CLM_USER=item_line.SPC_CLM_USER,
-                            SPC_CLM_KOD=item_line.SPC_CLM_KOD,
-                            SPC_CLM_FACTORY=item_line.SPC_CLM_FACTORY,
-                            edizm=edizm,
-                            section=item_line.section,
-                            section_num=item_line.section_num,
-                            subsection=item_line.subsection,
+                    if item_line is not None:
+                        launch_item_line, created = Launch_item_line.objects.get_or_create(
+                            child=item_line.child,
+                            parent=item_line.parent,
+                            launch=launch,
+
+                            defaults=dict(
+                                item_line=item_line,
+                                SPC_CLM_FORMAT=item_line.SPC_CLM_FORMAT,
+                                SPC_CLM_ZONE=item_line.SPC_CLM_ZONE,
+                                SPC_CLM_POS=item_line.SPC_CLM_POS,
+                                SPC_CLM_MARK=item_line.SPC_CLM_MARK,
+                                SPC_CLM_NAME=item_line.SPC_CLM_NAME,
+                                SPC_CLM_COUNT=count,
+                                SPC_CLM_NOTE=item_line.SPC_CLM_NOTE,
+                                SPC_CLM_MASSA=item_line.SPC_CLM_MASSA,
+                                SPC_CLM_MATERIAL=item_line.SPC_CLM_MATERIAL,
+                                SPC_CLM_USER=item_line.SPC_CLM_USER,
+                                SPC_CLM_KOD=item_line.SPC_CLM_KOD,
+                                SPC_CLM_FACTORY=item_line.SPC_CLM_FACTORY,
+                                edizm=edizm,
+                                section=item_line.section,
+                                section_num=item_line.section_num,
+                                subsection=item_line.subsection,
+                            )
                         )
-                    )
 
-                    if created:
-                        logger.debug(f'Created : launch_item_line :  {launch_item_line}')
-                        pass
-                    else:
-                        logger.debug(f'Existed : launch_item_line :  {launch_item_line}')
+                        if created:
+                            logger.debug(f'Created : launch_item_line :  {launch_item_line}')
+                            pass
+                        else:
+                            logger.debug(f'Existed : launch_item_line :  {launch_item_line}')
 
+                    section = launch_item_line.section if launch_item_line is not None else 'Нет'
                     if item_ref.parent:
-                        if first_step == False and demand != None:
+                        if first_step == False and demand is not None:
                             self.rec_operations_data(
                                 item=item_ref.parent,
-                                section=launch_item_line.section,
+                                section=section,
                                 get_full_path=items_refs_stack.get_full_path,
                                 key=key,
                                 first_step=first_step,
@@ -494,7 +513,7 @@ class Launches_ext:
 
                     self.rec_operations_data(
                         item=item_ref.child,
-                        section=launch_item_line.section,
+                        section=section,
                         get_full_path=items_refs_stack.get_full_path,
                         key=key,
                         first_step=first_step,
@@ -506,7 +525,7 @@ class Launches_ext:
                         settings.LOCKS.release(key)
                         raise ProgressDroped(progress_deleted)
 
-                if demand != None:
+                if demand is not None:
                     demand.status = settings.PROD_OPERS_STACK.DEMAND_LAUNCHED
                     demand.save()
                 settings.LOCKS.release(key)
@@ -537,7 +556,7 @@ class Launches_ext:
 
         user = data.get('user')
         id = data.get('id')
-        parentlaunch = Launches.objects.get(id=id) if id != None else None
+        parentlaunch = Launches.objects.get(id=id) if id is not None else None
 
         date = StrToDate(date)
         delAttr(data, 'user')
@@ -545,7 +564,7 @@ class Launches_ext:
         if isinstance(demands, list):
             for demand_id in demands:
                 demand = Demand_view.objects.get(id=demand_id)
-                # if demand.qty_for_launch == None or demand.qty_for_launch == 0:
+                # if demand.qty_for_launch is None or demand.qty_for_launch == 0:
                 #     raise Exception(f'Не указано количестово для запуска заказа № {demand.code} от {DateToStr(demand.date, hours=3)}')
                 # elif demand.qty_for_launch > demand.tail_qty:
                 #     raise Exception(f'Затребован болшее количество ({demand.qty_for_launch}) количестово для запуска заказа № {demand.code} от {DateToStr(demand.date, hours=3)}, чем имеется в наличии ({demand.tail_qty})')
