@@ -4,7 +4,7 @@ from django.conf import settings
 from django.db.models import DateTimeField, BooleanField, DecimalField, PositiveIntegerField
 
 from isc_common import setAttr
-from isc_common.common import blinkString, green, red
+from isc_common.common import blinkString, green
 from isc_common.fields.related import ForeignKeyProtect
 from isc_common.http.DSRequest import DSRequest
 from isc_common.isc.data_binding.advanced_criteria import AdvancedCriteria
@@ -67,15 +67,15 @@ class Launches_viewQuerySet(BaseRefQuerySet):
                                 ):
                                     if launch_item_order.qty_odd > 0:
                                         res.append(setAttr(record, 'value_odd', blinkString(DecimalToStr(launch_item_order.qty_odd), blink=False, color=green, bold=True)))
-                                    else:
-                                        res.append(setAttr(record, 'value_odd', blinkString(DecimalToStr(launch_item_order.qty_odd), blink=True, color=red, bold=True)))
+                                    # else:
+                                    #     res.append(setAttr(record, 'value_odd', blinkString(DecimalToStr(launch_item_order.qty_odd), blink=True, color=red, bold=True)))
                         else:
                             for buffers_item in Buffers.objects.filter(item=record_0.item, last_operation=record_0.childs[record_0.production_operation_num - 2].production_operation):
                                 value_odd = buffers_item.value
 
                                 if value_odd > 0:
                                     record = Launches_viewManager.getRecord(Launches_view.objects.get(id=buffers_item.launch.id))
-                                    res.append(setAttr(record, 'value_odd',blinkString(DecimalToStr(value_odd), blink=False, color=green, bold=True)))
+                                    res.append(setAttr(record, 'value_odd', blinkString(DecimalToStr(value_odd), blink=False, color=green, bold=True)))
 
         return res
 
@@ -116,7 +116,7 @@ class Launches_viewManager(BaseRefManager):
 
             'status_id': record.status.id,
             'status__code': record.status.code,
-            'status__name': record.status.name,
+            'status__name': record.status.name if record.code != '000' else '',
 
             'qty': DecimalToStr(record.qty),
             'qty_made': record.qty_made,
