@@ -1,6 +1,7 @@
 from isc_common.http.DSResponse import DSResponseUpdate, DSResponseAdd, DSResponse, JsonResponseWithException
 from isc_common.http.RPCResponse import RPCResponseConstant
 from isc_common.http.response import JsonResponse
+
 from kaf_pas.sales.models.demand_materials import Demand_materials, Demand_materialsManager
 
 
@@ -11,9 +12,9 @@ def Demand_materials_Fetch(request):
         DSResponse(
             request=request,
             data=Demand_materials.objects.
+                filter().
                 get_range_rows1(
                 request=request,
-                # remove_fields=['material'],
                 function=Demand_materialsManager.getRecord
             ),
             status=RPCResponseConstant.statusSuccess).response)
